import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { UpdateHomePageAboutSectionCmsDto } from "./dto/update-home-page-about-section-cms.dto";
import { HomePageAboutSectionCmsService } from "./home-page-about-section-cms.service";

@Controller({ path: "home-page-about-section-cms", version: Constants.API_VERSION_1 })

export class HomePageAboutSectionCmsController {
    constructor(private readonly service: HomePageAboutSectionCmsService) {}

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "image", maxCount: 1 }
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateHomePageAboutSectionCmsDto,
        @UploadedFiles() files: {
            image: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
