import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateContactModelDto } from "./dto/create-contact-model.dto";
import { UpdateContactModelDto } from "./dto/update-contact-model.dto";
import { ContactModelEntity } from "./entity/contact-model.entity";

@EntityRepository(ContactModelEntity)
export class ContactModelRepository extends Repository<ContactModelEntity> {

    async createEntity(dto: CreateContactModelDto): Promise<ContactModelEntity | Error> {
        try {
            const {
                name,
                email,
                message
            } = dto;
            const entity = this.create({
                name,
                email,
                message
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<ContactModelEntity[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false },
                order: { createdAt: "DESC" }
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ContactModelEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateContactModelDto): Promise<ContactModelEntity | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(ContactModelEntity)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async countAllQuery(): Promise<any | Error> {
        try {
            return await this.count({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}