import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateSocialLinksDto } from "./dto/create-social-links.dto";
import { UpdateSocialLinksDto } from "./dto/update-social-links.dto";
import { SocialLinksEntity } from "./entities/social-links.entity";

@EntityRepository(SocialLinksEntity)
export class SocialLinksRepository extends Repository<SocialLinksEntity> {
    async createEntity(dto: CreateSocialLinksDto): Promise<SocialLinksEntity | Error> {
        try {
            const {
                icon,
                link
            } = dto;
            const entity = this.create({
                icon,
                link
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<SocialLinksEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<SocialLinksEntity[] | Error> {
        try {
            return await this.find({
                where: {
                    ...query,
                    isDeleted: false
                },
                order: {
                    createdAt: "DESC"
                }
            });
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<SocialLinksEntity[] | Error> {
        try {
            return await this.find({
                order: {
                    createdAt: "ASC"
                }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(SocialLinksEntity)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateSocialLinksDto): Promise<SocialLinksEntity | Error> {
        try {
            await this.update(id, {
                icon: dto.icon,
                link: dto.link
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }
}